@@ -205,7 +205,6 @@ connect_now_show_settings_dialog(GtkWidget* widget, gpointer data)
   icon_size_scale = gtk_hscale_new_with_range(50, 200, 10);
   gtk_scale_set_digits(GTK_SCALE(icon_size_scale), 0);
   gtk_range_set_value(GTK_RANGE(icon_size_scale), desktop_plugin->widget_size);
-
   // dialog
   dialog = gtk_dialog_new_with_buttons("Settings",
 				       NULL,
@@ -402,7 +401,7 @@ connect_now_switch_normal_mode(ConnectNowHomePlugin* desktop_plugin)
 }
 
 gint
-connect_now_button_press(GtkWidget* widget, GdkEventButton *event, ConnectNowHomePlugin* desktop_plugin)
+connect_now_button_release(GtkWidget* widget, GdkEventButton *event, ConnectNowHomePlugin* desktop_plugin)
 {
   if(desktop_plugin->connection_name == NULL)
   {
@@ -454,7 +453,7 @@ connect_now_home_plugin_init(ConnectNowHomePlugin *desktop_plugin)
   desktop_plugin->connect_now = FALSE;
   desktop_plugin->con = con_ic_connection_new();
   desktop_plugin->widget_size = CONNECTNOW_DEFAULT_WIDGET_WIDTH;
-  desktop_plugin->hide_connection_name = FALSE;
+  desktop_plugin->hide_connection_name = TRUE;
   g_signal_connect(desktop_plugin->con, "connection-event", G_CALLBACK(connect_now_connection_changed), desktop_plugin);
   g_object_set(desktop_plugin->con, "automatic-connection-events", TRUE);
 
@@ -463,7 +462,7 @@ connect_now_home_plugin_init(ConnectNowHomePlugin *desktop_plugin)
   gtk_widget_set_size_request(contents, desktop_plugin->widget_size, desktop_plugin->widget_size);
   gtk_container_add(GTK_CONTAINER(desktop_plugin), contents);
   hd_home_plugin_item_set_settings (HD_HOME_PLUGIN_ITEM (desktop_plugin), TRUE);
-  g_signal_connect(GTK_CONTAINER(contents), "button-press-event", G_CALLBACK(connect_now_button_press), desktop_plugin);
+  g_signal_connect(GTK_CONTAINER(contents), "button-release-event", G_CALLBACK(connect_now_button_release), desktop_plugin);
   g_signal_connect(desktop_plugin, "show-settings", G_CALLBACK(connect_now_show_settings_dialog), NULL);
 }
 
@@ -517,6 +516,7 @@ connect_now_expose(GtkWidget* widget, GdkEventExpose *event)
   {
     image = CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage;
   }
+
   gdk_cairo_set_source_pixbuf(cr, image, 0.0, 0.0);
   cairo_paint(cr);
 
@@ -567,7 +567,7 @@ static void
 connect_now_plugin_finalize(GObject *object)
 {
   ConnectNowHomePlugin *desktop_plugin = CONNECT_NOW_HOME_PLUGIN(object);
-  g_object_unref (desktop_plugin->con);
+  g_object_unref(desktop_plugin->con);
   g_free(desktop_plugin->connection_id);
   g_free(desktop_plugin->current_connection_id);
   g_free(desktop_plugin->connection_name);
